@@ -6,7 +6,7 @@ use warnings;
 	package Ask;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.007';
+	our $VERSION   = '0.008';
 	
 	use Carp qw(croak);
 	use Moo::Role qw();
@@ -18,7 +18,7 @@ use warnings;
 		require     => 0,
 		sub_name    => '__plugins',
 	);
-	use namespace::sweep;
+	use namespace::autoclean;
 	
 	sub import {
 		shift;
@@ -39,7 +39,7 @@ use warnings;
 		
 		my @implementations =
 			reverse sort { $a->quality <=> $b->quality }
-			grep { use_package_optimistically($_)->DOES('Ask::API') }
+			grep { eval { use_package_optimistically($_)->DOES('Ask::API') } }
 			$class->plugins;
 		
 		if (exists $ENV{PERL_ASK_BACKEND}) {
@@ -355,7 +355,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012-2013 by Toby Inkster.
+This software is copyright (c) 2012-2013, 2020 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
