@@ -6,15 +6,20 @@ use warnings;
 	package Ask::Gtk;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.007';
-
+	our $VERSION   = '0.008';
+	
 	use Moo;
 	use Gtk2 -init;
 	use URI;
-	use namespace::sweep;
-
+	use namespace::autoclean;
+	
 	with 'Ask::API';
 	
+	sub is_usable {
+		my ($self) = @_;
+		return !! $ENV{'DISPLAY'};
+	}
+	
 	sub info
 	{
 		my ($self, %o) = @_;
@@ -223,7 +228,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012-2013 by Toby Inkster.
+This software is copyright (c) 2012-2013, 2020 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
