@@ -6,14 +6,19 @@ use warnings;
 	package Ask::Wx;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.007';
-
+	our $VERSION   = '0.008';
+	
 	use Moo;
 	use Wx;
-	use namespace::sweep;
-
+	use namespace::autoclean;
+	
 	with 'Ask::API';
 	
+	sub is_usable {
+		my ($self) = @_;
+		return !! $ENV{'DISPLAY'};
+	}
+	
 	sub quality {
 		return 10;  # raise to 50 once multi file selection implemented
 	}
@@ -101,7 +106,7 @@ use warnings;
 		return if $return < 0;
 		return $o{choices}[$return][0];
 	}
-
+	
 	sub multiple_choice
 	{
 		my ($self, %o) = @_;
@@ -147,7 +152,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012-2013 by Toby Inkster.
+This software is copyright (c) 2012-2013, 2020 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
