@@ -6,16 +6,15 @@ use warnings;
 	package Ask::Zenity;
 	
 	our $AUTHORITY = 'cpan:TOBYINK';
-	our $VERSION   = '0.007';
+	our $VERSION   = '0.008';
 	
 	use Moo;
 	use File::Which qw(which);
 	use System::Command;
-	use namespace::sweep;
+	use namespace::autoclean;
 	
 	has zenity_path => (
 		is       => 'ro',
-		isa      => sub { die "$_[0] not executable" unless -x $_[0] },
 		default  => sub { which('zenity') || '/usr/bin/zenity' },
 	);
 	
@@ -26,6 +25,13 @@ use warnings;
 	
 	with 'Ask::API';
 	
+	sub is_usable {
+		my ($self) = @_;
+		return unless !! $ENV{'DISPLAY'};
+		return unless -x $self->zenity_path;
+		return 1;
+	}
+	
 	sub quality {
 		return 40;
 	}
@@ -153,7 +159,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012-2013 by Toby Inkster.
+This software is copyright (c) 2012-2013, 2020 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
